@@ -171,16 +171,13 @@ class Renderer(base.Renderer, CategoryUtils):
 	    return '0'
 	
 	image = "++resource++collective.contentMapper.images/SmallMarker.png"
-	if nr <= int(levels[0]):
-	    #Small
-	    image = "++resource++collective.contentMapper.images/SmallMarker.png"
-	elif nr <= int(levels[1]):
+	
+	if nr >= int(levels[1]) and nr < int(levels[2]):
 	    #medium
 	    image = "++resource++collective.contentMapper.images/MediumMarker.png"
-	elif nr <= int(levels[2]):
+	elif nr >= int(levels[2]):
 	    #big
 	    image = "++resource++collective.contentMapper.images/BigMarker.png"
-	    
 	
 	return image
 	
